use Test::More tests => 15;

use strict;
use warnings;
use RPM::SpecEditor;

my $spec = RPM::SpecEditor->new(string => <<EOM);
Name:     namevalue
Requires: r1 >= v1, r2 >= v2
Provides: p1
EOM
ok($spec, 'Spec parsed');
my $new;

my ($dependency) = $spec->dom->findDependencies('Requires', 'r1');

$dependency->symbol('newr1');
ok($spec->save(string => \$new), 'Spec saved');
is($new, <<EOM, 'r1 symbol replaced with newr1');
Name:     namevalue
Requires: newr1 >= v1, r2 >= v2
Provides: p1
EOM

$dependency->operator('<');
ok($spec->save(string => \$new), 'Spec saved');
is($new, <<EOM, 'r1 operator replaced with <');
Name:     namevalue
Requires: newr1 < v1, r2 >= v2
Provides: p1
EOM

$dependency->version('newv2');
ok($spec->save(string => \$new), 'Spec saved');
is($new, <<EOM, 'r1 version replaced with newv2');
Name:     namevalue
Requires: newr1 < newv2, r2 >= v2
Provides: p1
EOM

$dependency->version(undef);
ok($spec->save(string => \$new), 'Spec saved');
is($new, <<EOM, 'r1 version removed');
Name:     namevalue
Requires: newr1, r2 >= v2
Provides: p1
EOM

$dependency->version('newestv1');
ok($spec->save(string => \$new), 'Spec saved');
is($new, <<EOM, 'newestv1 version added to r1');
Name:     namevalue
Requires: newr1 >= newestv1, r2 >= v2
Provides: p1
EOM

$dependency->remove();
ok($spec->save(string => \$new), 'Spec saved');
is($new, <<EOM, 'r1 dependency removed');
Name:     namevalue
Requires: r2 >= v2
Provides: p1
EOM

($dependency) = $spec->dom->findDependencies('Requires', 'r2');
$dependency->remove();
ok($spec->save(string => \$new), 'Spec saved');
is($new, <<EOM, 'Last r2 dependency removed');
Name:     namevalue
Provides: p1
EOM
