use Test::More tests => 11;

use strict;
use warnings;
use RPM::SpecEditor;

my $spec = RPM::SpecEditor->new(string => <<EOM);
Name:     namevalue
Requires: r1 >= v1, r2 >= v2
Provides: p1
EOM
ok($spec, 'Spec parsed');
my ($new_spec, $dependency, $new_dependency);

($dependency) = $spec->dom->findDependencies('Requires', 'r1');
$new_dependency = RPM::SpecEditor::Node->new(
    type => 'dependency',
    symbol => 'r0',
    version => 'v0'
);
$dependency->insertBefore($new_dependency);
ok($spec->save(string => \$new_spec), 'Spec saved');
is($new_spec, <<EOM, 'dependency r0 added at the first place');
Name:     namevalue
Requires: r0 >= v0, r1 >= v1, r2 >= v2
Provides: p1
EOM

($dependency) = $spec->dom->findDependencies('Requires', 'r2');
$new_dependency = RPM::SpecEditor::Node->new(
    type => 'dependency',
    symbol => 'r15',
);
$dependency->insertBefore($new_dependency);
ok($spec->save(string => \$new_spec), 'Spec saved');
is($new_spec, <<EOM, 'dependency r15 added before the last place');
Name:     namevalue
Requires: r0 >= v0, r1 >= v1, r15, r2 >= v2
Provides: p1
EOM

($dependency) = $spec->dom->findDependencies('Requires', 'r2');
$new_dependency = RPM::SpecEditor::Node->new(
    type => 'dependency',
    symbol => 'r3',
);
$dependency->insertAfter($new_dependency);
ok($spec->save(string => \$new_spec), 'Spec saved');
is($new_spec, <<EOM, 'dependency r3 added after the last place');
Name:     namevalue
Requires: r0 >= v0, r1 >= v1, r15, r2 >= v2, r3
Provides: p1
EOM

($dependency) = $spec->dom->findDependencies('Requires', 'r2');
$dependency = $dependency->getParent;
$new_dependency = RPM::SpecEditor::Node->new(
    type => 'Requires',
    separator => ' '
)->addChild(RPM::SpecEditor::Node->new(
        type => 'dependency',
        symbol => 'foo',
    )
);
$dependency->insertBefore($new_dependency);
ok($spec->save(string => \$new_spec), 'Spec saved');
is($new_spec, <<EOM, 'dependency foo added before r2 require line');
Name:     namevalue
Requires: foo
Requires: r0 >= v0, r1 >= v1, r15, r2 >= v2, r3
Provides: p1
EOM

($dependency) = $spec->dom->findDependencies('Requires', 'r2');
$dependency = $dependency->getParent;
$new_dependency = RPM::SpecEditor::Node->new(
    type => 'Requires',
    separator => ' '
)->addChild(RPM::SpecEditor::Node->new(
        type => 'dependency',
        symbol => 'bar',
    )
);
$dependency->insertAfter($new_dependency);
ok($spec->save(string => \$new_spec), 'Spec saved');
is($new_spec, <<EOM, 'dependency bar added after r2 require line');
Name:     namevalue
Requires: foo
Requires: r0 >= v0, r1 >= v1, r15, r2 >= v2, r3
Requires: bar
Provides: p1
EOM

