use Test::More tests => 54;

use strict;
use warnings;
use RPM::SpecEditor;

my $spec = RPM::SpecEditor->new(file => 't/1.spec');
isa_ok($spec, 'RPM::SpecEditor');

my $dom = $spec->dom;
isa_ok($dom, 'RPM::SpecEditor::Node');

my @nodes = $dom->getAllChildren;

is($nodes[0]->type, 'comment', 'First node is a comment');
is($nodes[0]->line, 1, 'First node is on line 1');
is($nodes[0]->leftpad, ' ', q{First node's left padding matches});
is($nodes[0]->separator, ' ', q{First node's separator matches});
is($nodes[0]->value, 'A comment', q{First node's text matches});

is($nodes[1]->type, 'tag', 'Second node is a tag');
is($nodes[1]->line, 2, 'Second node is on line 2');
is($nodes[1]->leftpad, '', q{Second node's left padding matches});
is($nodes[1]->separator, '       ', q{Second node's separator matches});
is($nodes[1]->name, 'Name', 'Second node is a Name tag');
is($nodes[1]->value, 'namevalue', q{Second node's text matches});

is($nodes[2]->type, 'tag', 'Third node is a tag');
is($nodes[2]->line, 3, 'Third node is on line 3');
is($nodes[2]->leftpad, '', q{Third node's left padding matches});
is($nodes[2]->separator, '    ', q{Third node's separator matches});
is($nodes[2]->name, 'Version', 'Third node is a Version tag');
is($nodes[2]->value, 'versionvalue', q{Third node's text matches});

is($nodes[11]->type, 'BuildRequires', '11th node is a BuildRequires');
is($nodes[11]->line, 12, '11th node is on line 12');
is($nodes[11]->leftpad, '', q{11th node's left padding matches});
is($nodes[11]->separator, '  ', q{11th node's separator matches});
is($nodes[11]->value, 'br1 >= 0:1-2', q{11th node's text matches});
is($nodes[11]->getChildCount, 1, '11th node has one child');

my $dependency = $nodes[11]->getChild(0);
is($dependency->type, 'dependency', q{BR's child is a dependency});
is($dependency->line, $nodes[11]->line, q{BR's child is on the same line});
is($dependency->symbol, 'br1', q{BR's symbol is br1});
is($dependency->operatorLeftPad, ' ', q{BR's operatorLeftPad is one space});
is($dependency->operator, '>=', q{BR's operator is >=});
is($dependency->versionLeftPad, ' ', q{BR's versionLeftPad is one space});
is($dependency->version, '0:1-2', q{BR's version is 0:1-2});

is($nodes[12]->type, 'Requires', '12th node is a Requires');
is($nodes[12]->line, 13, '12th node is on line 13');
is($nodes[12]->leftpad, '', q{12th node's left padding matches});
is($nodes[12]->separator, '       ', q{12th node's separator matches});
is($nodes[12]->value, 'r1, r2, r3 >= 1', q{12th node's text matches});
is($nodes[12]->getChildCount, 3, '12th node has three children');

$dependency = $nodes[12]->getChild(0);
is($dependency->type, 'dependency', q{1st R's child is a dependency});
is($dependency->line, $nodes[12]->line, q{1st R's child is on the same line});
is($dependency->symbol, 'r1', q{1st R's symbol is r1});
is($dependency->operatorLeftPad, undef, q{1st R's operatorLeftPad is none});
is($dependency->operator, undef, q{1st R's operator is none});
is($dependency->versionLeftPad, undef, q{1st R's versionLeftPad is none});
is($dependency->version, undef, q{1st R's version is none});
is($dependency->rightPad, ', ', q{1st R's rightPad is a comma with a space});

$dependency = $nodes[12]->getChild(2);
is($dependency->type, 'dependency', q{3rd R's child is a dependency});
is($dependency->line, $nodes[12]->line, q{3rd R's child is on the same line});
is($dependency->symbol, 'r3', q{3rd R's symbol is r3});
is($dependency->operatorLeftPad, ' ', q{3rd R's operatorLeftPad is a space});
is($dependency->operator, '>=', q{3rd R's operator is >=});
is($dependency->versionLeftPad, ' ', q{3rd R's versionLeftPad is a space});
is($dependency->version, '1', q{3rd R's version is 1});
is($dependency->rightPad, undef, q{3rd R's rightPad is none});
