use Test::More tests => 10;

use strict;
use warnings;
use RPM::SpecEditor;
use File::Temp;
use Encode;

sub load {
    my $file = shift;
    open(my $fh, '<', $file) or die;
    my $text;
    {
        local $/ = undef;
        $text = <$fh>;
    }
    if ($!) { die; }
    close $fh;
    return $text;
}

my $spec = RPM::SpecEditor->new(file => 't/1.spec');
ok($spec, 'Spec parsed from a file');
my $old = load('t/1.spec');

{
    my $tmp = eval { File::Temp->new() };
    ok($tmp, 'Temporary file created');
    ok($spec->save(file => $tmp->filename), 'Spec saved into a file');

    my $new = load($tmp->filename);
    is($new, $old, 'Serialization to a file is idempotent');

    unlink $tmp->filename;
}

{
    my $tmp = eval { File::Temp->new() };
    ok($tmp, 'Temporary file created');
    ok($spec->save(handle => $tmp), 'Spec saved into a handle');

    ok($tmp->flush, 'Handle content flushed to a file');
    my $new = load($tmp->filename);
    is($new, $old, 'Serialization to a handle is idempotent');

    unlink $tmp->filename;
}

{
    my $new;
    ok($spec->save(string => \$new), 'Spec saved into a string');
    $new = Encode::encode('UTF-8', $new);

    is($new, $old, 'Serialization to a string is idempotent');
}
